@@ -7,7 +7,7 @@ use Path::Tiny;
 use Perl::Tidy;
 use Pod::Tidy;
 
-our $VERSION = '0.11.6';
+our $VERSION = '0.11.10';
 
 my $temp_dir;
 
@@ -133,6 +133,24 @@ sub run {
 
         $self->tmp_sys( qw/git add /, $file );
 
+        if ( $file eq $self->{readme_from} ) {
+            require Pod::Text;
+            my $parser = Pod::Text->new( sentence => 0, width => 78 );
+            my $tmp_readme = $temp_dir->child('README');
+
+            $parser->parse_from_file( $file, $tmp_readme->stringify );
+
+            if (
+                system("git ls-files --error-unmatch README > /dev/null 2>&1")
+                == 0 )
+            {
+                $self->tmp_sys(qw/git add README/);
+            }
+
+            print "  $self->{me}: copy README\n" if $self->{opts}->{verbose};
+            copy $tmp_readme, 'README';
+        }
+
         # Redo the whole thing again for partially modified files
         if ( $partial{$file} ) {
             print "  $self->{me}: copy $file $tmp_file\n"
@@ -197,7 +215,7 @@ App::githook_perltidy::pre_commit - git pre-commit hook
 
 =head1 VERSION
 
-0.11.6 (2018-06-28)
+0.11.10 (2018-07-14)
 
 =head1 SEE ALSO
 
